@@ -2,7 +2,7 @@
 
 import json
 
-from tap_rest_api_msdk.client import flatten_json
+from tap_rest_api_msdk.utils import flatten_json
 
 SAMPLE_CONFIG = {
     "api_url": "https://url.test",
